@@ -66,6 +66,11 @@ class CreatePhysicalConnectionRequest(RpcRequest):
 
 	def set_Type(self, Type):  # String
 		self.add_query_param('Type', Type)
+	def get_ResourceGroupId(self): # String
+		return self.get_query_params().get('ResourceGroupId')
+
+	def set_ResourceGroupId(self, ResourceGroupId):  # String
+		self.add_query_param('ResourceGroupId', ResourceGroupId)
 	def get_RedundantPhysicalConnectionId(self): # String
 		return self.get_query_params().get('RedundantPhysicalConnectionId')
 
